interrogatio
============

A python library to prompt user for inputs in a terminal application.


What is interrogatio
********************

interrogatio is a python 2/3 library based on the `python-prompt-toolkit
<https://github.com/prompt-toolkit/python-prompt-toolkit>`_ and inspired by `PyInquirer
<https://github.com/CITGuru/PyInquirer/>`_ that help CLI developers to ask users for inputs.


Questions can be rendered onto the terminal prompt or as curses dialogs.


Documentation
*************

Interrogatio is still under heavy development.


Getting started
***************

Requirements
------------

interrogatio depends on the python-prompt-toolkit library and its dependencies.

Installation
------------

Using pip
^^^^^^^^^

::

    $ pip install interrogatio


Contributing
------------

If you want to contribute to the project, you can submit bugs, feature requests, translations or fork the github repository and submit your pull request.

::

    $ pip install -e '.[test]'
    $ python setup.py test


License
-------
interrogatio is released under the `BSD 3-Clause "New" or "Revised" License <https://opensource.org/licenses/BSD-3-Clause>`_.
